@@ -31,28 +31,46 @@ def _generate_datetime_validator(format_option, dateformat_string):
             datetime.strptime(value, dateformat_string)
         except ValueError:
             raise ValidationError(
-                    "Value %(value)r of field '%(fieldname)s' is not in '%(format_option)s' format" % locals())
+                "Value %(value)r of field '%(fieldname)s' is not in "
+                "'%(format_option)s' format" % locals())
 
     return validate_format_datetime
 
-validate_format_date_time  = _generate_datetime_validator('date-time', '%Y-%m-%dT%H:%M:%SZ')
-validate_format_date       = _generate_datetime_validator('date', '%Y-%m-%d')
-validate_format_time       = _generate_datetime_validator('time', '%H:%M:%S')
+validate_format_date_time = _generate_datetime_validator('date-time',
+                                                         '%Y-%m-%dT%H:%M:%SZ')
+validate_format_date = _generate_datetime_validator('date', '%Y-%m-%d')
+validate_format_time = _generate_datetime_validator('time', '%H:%M:%S')
 
 
 def validate_format_utc_millisec(validator, fieldname, value, format_option):
     if not isinstance(value, (int, float)):
-        raise ValidationError("Value %(value)r of field '%(fieldname)s' is not a number" % locals())
+        raise ValidationError("Value %(value)r of field '%(fieldname)s' is "
+                              "not a number" % locals())
 
     if not value > 0:
-        raise ValidationError("Value %(value)r of field '%(fieldname)s' is not a positive number" % locals())
+        raise ValidationError("Value %(value)r of field '%(fieldname)s' is "
+                              "not a positive number" % locals())
+
+
+def validate_format_ip_address(validator, fieldname, value, format_option):
+    try:
+        socket.inet_aton(value)
+        # Make sure we expect "X.X.X.X" as socket.inet_aton() converts "1"
+        # to "0.0.0.1"
+        ip = len(value.split('.')) == 4
+    except:
+        ip = False
+    if not ip:
+        raise ValidationError("Value %(value)r of field '%(fieldname)s' is "
+                              "not a ip-address" % locals())
 
 
 DEFAULT_FORMAT_VALIDATORS = {
-    'date-time'    : validate_format_date_time,
-    'date'         : validate_format_date,
-    'time'         : validate_format_time,
-    'utc-millisec' : validate_format_utc_millisec,
+    'date-time': validate_format_date_time,
+    'date': validate_format_date,
+    'time': validate_format_time,
+    'utc-millisec': validate_format_utc_millisec,
+    'ip-address': validate_format_ip_address,
 }
 
 
@@ -68,7 +86,8 @@ class SchemaValidator(object):
         schema attribute True by default.
     '''
 
-    def __init__(self, format_validators=None, required_by_default=True, blank_by_default=False):
+    def __init__(self, format_validators=None, required_by_default=True,
+                 blank_by_default=False):
         if format_validators is None:
             format_validators = DEFAULT_FORMAT_VALIDATORS.copy()
 
@@ -100,15 +119,6 @@ class SchemaValidator(object):
     def validate_type_null(self, val):
         return val is None
 
-    def validate_type_ip_address(self, val):
-        try:
-            socket.inet_aton(val)
-            # Make sure we expect "X.X.X.X" as socket.inet_aton() converts "1"
-            # to "0.0.0.1"
-            return len(val.split('.')) == 4
-        except:
-            return False
-
     def validate_type_any(self, val):
         return True
 
@@ -144,7 +154,8 @@ class SchemaValidator(object):
                     except ValidationError:
                         pass
                 if not datavalid:
-                    self._error("Value %(value)r for field '%(fieldname)s' is not of type %(fieldtype)s",
+                    self._error("Value %(value)r for field '%(fieldname)s' is "
+                                "not of type %(fieldtype)s",
                                 value, fieldname, fieldtype=fieldtype)
             elif isinstance(fieldtype, dict):
                 try:
@@ -154,13 +165,14 @@ class SchemaValidator(object):
             else:
                 try:
                     type_checker = getattr(self, 'validate_type_%s' %
-                                           fieldtype.replace('-', '_'))
+                                           fieldtype)
                 except AttributeError:
                     raise SchemaError("Field type '%s' is not supported." %
                                       fieldtype)
 
                 if not type_checker(value):
-                    self._error("Value %(value)r for field '%(fieldname)s' is not of type %(fieldtype)s",
+                    self._error("Value %(value)r for field '%(fieldname)s' "
+                                "is not of type %(fieldtype)s",
                                 value, fieldname, fieldtype=fieldtype)
 
     def validate_properties(self, x, fieldname, schema, properties=None):
@@ -176,7 +188,8 @@ class SchemaValidator(object):
                         self.__validate(eachProp, value,
                                         properties.get(eachProp))
                 else:
-                    raise SchemaError("Properties definition of field '%s' is not an object" % fieldname)
+                    raise SchemaError("Properties definition of field '%s' is "
+                                      "not an object" % fieldname)
 
     def validate_items(self, x, fieldname, schema, items=None):
         '''
@@ -187,15 +200,20 @@ class SchemaValidator(object):
             value = x.get(fieldname)
             if isinstance(value, (list, tuple)):
                 if isinstance(items, (list, tuple)):
-                    if not 'additionalItems' in schema and len(items) != len(value):
-                        self._error("Length of list %(value)r for field '%(fieldname)s' is not equal to length of schema list",
-                                    value, fieldname)
+                    if (not 'additionalItems' in schema and
+                        len(items) != len(value)):
+                        self._error("Length of list %(value)r for field "
+                                    "'%(fieldname)s' is not equal to length "
+                                    "of schema list", value, fieldname)
                     else:
                         for itemIndex in range(len(items)):
                             try:
-                                self.validate(value[itemIndex], items[itemIndex])
+                                self.validate(value[itemIndex],
+                                              items[itemIndex])
                             except ValueError as e:
-                                raise type(e)("Failed to validate field '%s' list schema: %s" % (fieldname, e))
+                                raise type(e)("Failed to validate field '%s' "
+                                              "list schema: %s" %
+                                              (fieldname, e))
                 elif isinstance(items, dict):
                     for eachItem in value:
                         try:
@@ -205,9 +223,12 @@ class SchemaValidator(object):
                             # with 'list item' so error messages make sense
                             old_error = str(e).replace("field '_data'",
                                                        'list item')
-                            raise type(e)("Failed to validate field '%s' list schema: %s" % (fieldname, old_error))
+                            raise type(e)("Failed to validate field '%s' list "
+                                          "schema: %s" %
+                                          (fieldname, old_error))
                 else:
-                    raise SchemaError("Properties definition of field '%s' is not a list or an object" % fieldname)
+                    raise SchemaError("Properties definition of field '%s' is "
+                                      "not a list or an object" % fieldname)
 
     def validate_required(self, x, fieldname, schema, required):
         '''
@@ -224,22 +245,24 @@ class SchemaValidator(object):
         '''
         value = x.get(fieldname)
         if isinstance(value, _str_type) and not blank and not value:
-            self._error("Value %(value)r for field '%(fieldname)s' cannot be blank'",
-                        value, fieldname)
+            self._error("Value %(value)r for field '%(fieldname)s' cannot be "
+                        "blank'", value, fieldname)
 
-    def validate_patternProperties(self, x, fieldname, schema, patternproperties=None):
+    def validate_patternProperties(self, x, fieldname, schema,
+                                   patternproperties=None):
 
         if patternproperties == None:
             patternproperties = {}
 
-        value_obj = x.get(fieldname)
+        value_obj = x.get(fieldname, {})
 
         for pattern, schema in patternproperties.items():
             for key, value in value_obj.items():
                 if re.match(pattern, key):
                     self.validate(value, schema)
 
-    def validate_additionalItems(self, x, fieldname, schema, additionalItems=False):
+    def validate_additionalItems(self, x, fieldname, schema,
+                                 additionalItems=False):
         value = x.get(fieldname)
 
         if not isinstance(value, (list, tuple)):
@@ -250,8 +273,9 @@ class SchemaValidator(object):
                 return
             elif len(value) != len(schema['items']):
                 #print locals(), value, len(value), len(schema['items'])
-                self._error("Length of list %(value)r for field '%(fieldname)s' is not equal to length of schema list",
-                             value, fieldname)
+                self._error("Length of list %(value)r for field "
+                            "'%(fieldname)s' is not equal to length of schema "
+                            "list", value, fieldname)
 
         remaining = value[len(schema['items']):]
         if len(remaining) > 0:
@@ -264,7 +288,7 @@ class SchemaValidator(object):
         specifically defined by the properties property
         '''
 
-        # Shouldn't be validating additionalProperties on non-dicts 
+        # Shouldn't be validating additionalProperties on non-dicts
         value = x.get(fieldname)
         if not isinstance(value, dict):
             return
@@ -287,12 +311,15 @@ class SchemaValidator(object):
                     # then we don't accept any additional properties.
                     if (isinstance(additionalProperties, bool) and
                         not additionalProperties):
-                        self._error("additional properties not defined by 'properties' are not allowed in field '%(fieldname)s'",
+                        self._error("additional properties not defined by "
+                                    "'properties' are not allowed in field "
+                                    "'%(fieldname)s'",
                                     None, fieldname)
                     self.__validate(eachProperty, value,
                                     additionalProperties)
         else:
-            raise SchemaError("additionalProperties schema definition for field '%s' is not an object" % fieldname)
+            raise SchemaError("additionalProperties schema definition for "
+                              "field '%s' is not an object" % fieldname)
 
     def validate_requires(self, x, fieldname, schema, requires=None):
         warnings.warn('The "requires" attribute has been replaced by "dependencies"', DeprecationWarning)
@@ -310,7 +337,8 @@ class SchemaValidator(object):
             if isinstance(dependencies, (list, tuple)):
                 for dependency in dependencies:
                     if dependency not in x:
-                        self._error("Field '%(dependency)s' is required by field '%(fieldname)s'",
+                        self._error("Field '%(dependency)s' is required by "
+                                    "field '%(fieldname)s'",
                             None, fieldname, dependency=dependency)
             elif isinstance(dependencies, dict):
                 # NOTE: the version 3 spec is really unclear on what this means
@@ -318,8 +346,8 @@ class SchemaValidator(object):
                 # that if a key exists, the appropriate value exists
                 for k, v in dependencies.items():
                     if k in x and v not in x:
-                        self._error("Field '%(v)s' is required by field '%(k)s'",
-                                    None, fieldname, k=k, v=v)
+                        self._error("Field '%(v)s' is required by field "
+                                    "'%(k)s'", None, fieldname, k=k, v=v)
             else:
                 raise SchemaError("'dependencies' must be a string, "
                                   "list of strings, or dict")
@@ -335,8 +363,11 @@ class SchemaValidator(object):
         if x.get(fieldname) is not None:
             value = x.get(fieldname)
             if value is not None:
-                if type(value) in (int, float) and (not exclusive and value < minimum) or (exclusive and value <= minimum):
-                    self._error("Value %(value)r for field '%(fieldname)s' is less than minimum value: %(minimum)f",
+                if (type(value) in (int, float) and
+                    (not exclusive and value < minimum) or
+                    (exclusive and value <= minimum)):
+                    self._error("Value %(value)r for field '%(fieldname)s' is "
+                                "less than minimum value: %(minimum)f",
                                 value, fieldname, minimum=minimum)
 
     def validate_maximum(self, x, fieldname, schema, maximum=None):
@@ -350,8 +381,11 @@ class SchemaValidator(object):
         if x.get(fieldname) is not None:
             value = x.get(fieldname)
             if value is not None:
-                if type(value) in (int, float) and (not exclusive and value > maximum) or (exclusive and value >= maximum):
-                    self._error("Value %(value)r for field '%(fieldname)s' is greater than maximum value: %(maximum)f",
+                if (type(value) in (int, float) and
+                    (not exclusive and value > maximum) or
+                    (exclusive and value >= maximum)):
+                    self._error("Value %(value)r for field '%(fieldname)s' is "
+                                "greater than maximum value: %(maximum)f",
                                 value, fieldname, maximum=maximum)
 
     def validate_maxLength(self, x, fieldname, schema, length=None):
@@ -361,7 +395,8 @@ class SchemaValidator(object):
         '''
         value = x.get(fieldname)
         if isinstance(value, (_str_type, list, tuple)) and len(value) > length:
-            self._error("Length of value %(value)r for field '%(fieldname)s' must be less than or equal to %(length)d",
+            self._error("Length of value %(value)r for field '%(fieldname)s' "
+                        "must be less than or equal to %(length)d",
                         value, fieldname, length=length)
 
     def validate_minLength(self, x, fieldname, schema, length=None):
@@ -371,7 +406,8 @@ class SchemaValidator(object):
         '''
         value = x.get(fieldname)
         if isinstance(value, (_str_type, list, tuple)) and len(value) < length:
-            self._error("Length of value %(value)r for field '%(fieldname)s' must be greater than or equal to %(length)d",
+            self._error("Length of value %(value)r for field '%(fieldname)s' "
+                        "must be greater than or equal to %(length)d",
                         value, fieldname, length=length)
 
     validate_minItems = validate_minLength
@@ -398,7 +434,8 @@ class SchemaValidator(object):
         value = x.get(fieldname)
         if isinstance(value, _str_type):
             if not re.match(pattern, value):
-                self._error("Value %(value)r for field '%(fieldname)s' does not match regular expression '%(pattern)s'",
+                self._error("Value %(value)r for field '%(fieldname)s' does "
+                            "not match regular expression '%(pattern)s'",
                             value, fieldname, pattern=pattern)
 
     def validate_uniqueItems(self, x, fieldname, schema, uniqueItems=False):
@@ -441,9 +478,11 @@ class SchemaValidator(object):
         value = x.get(fieldname)
         if value is not None:
             if not isinstance(options, Container):
-                raise SchemaError("Enumeration %r for field '%s' must be a container", (options, fieldname))
+                raise SchemaError("Enumeration %r for field '%s' must be a "
+                                  "container", (options, fieldname))
             if value not in options:
-                self._error("Value %(value)r for field '%(fieldname)s' is not in the enumeration: %(options)r",
+                self._error("Value %(value)r for field '%(fieldname)s' is not "
+                            "in the enumeration: %(options)r",
                             value, fieldname, options=options)
 
     def validate_title(self, x, fieldname, schema, title=None):
@@ -453,7 +492,7 @@ class SchemaValidator(object):
 
     def validate_description(self, x, fieldname, schema, description=None):
         if not isinstance(description, (_str_type, type(None))):
-            raise SchemaError("The description for field '%s' must be a string."
+            raise SchemaError("The description for field '%s' must be a string"
                              % fieldname)
 
     def validate_divisibleBy(self, x, fieldname, schema, divisibleBy=None):
@@ -466,7 +505,8 @@ class SchemaValidator(object):
             raise SchemaError("'%r' <- divisibleBy can not be 0" % schema)
 
         if value % divisibleBy != 0:
-            self._error("Value %(value)r field '%(fieldname)s' is not divisible by '%(divisibleBy)s'.",
+            self._error("Value %(value)r field '%(fieldname)s' is not "
+                        "divisible by '%(divisibleBy)s'.",
                         x.get(fieldname), fieldname, divisibleBy=divisibleBy)
 
     def validate_disallow(self, x, fieldname, schema, disallow=None):
@@ -478,7 +518,8 @@ class SchemaValidator(object):
             self.validate_type(x, fieldname, schema, disallow)
         except ValidationError:
             return
-        self._error("Value %(value)r of type %(disallow)s is disallowed for field '%(fieldname)s'",
+        self._error("Value %(value)r of type %(disallow)s is disallowed for "
+                    "field '%(fieldname)s'",
                     x.get(fieldname), fieldname, disallow=disallow)
 
     def validate(self, data, schema):
